@@ -3,11 +3,17 @@ from __future__ import unicode_literals
 import os
 import sys
 import unittest
+import xml
 
 import pytest
 
 from pymediainfo import MediaInfo
 
+os_is_nt = os.name in ("nt", "dos", "os2", "ce")
+
+if sys.version_info < (3, 3):
+    FileNotFoundError = IOError
+
 data_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
 
 class MediaInfoTest(unittest.TestCase):
@@ -43,11 +49,14 @@ class MediaInfoTest(unittest.TestCase):
 
 class MediaInfoInvalidXMLTest(unittest.TestCase):
     def setUp(self):
+        if sys.version_info < (2, 7):
+            self._exc_class = xml.parsers.expat.ExpatError
+        else:
+            self._exc_class = xml.etree.ElementTree.ParseError
         with open(os.path.join(data_dir, 'invalid.xml'), 'r') as f:
             self.xml_data = f.read()
     def test_parse_invalid_xml(self):
-        mi = MediaInfo(MediaInfo._parse_xml_data_into_dom(self.xml_data))
-        self.assertEqual(len(mi.tracks), 0)
+        self.assertRaises(self._exc_class, MediaInfo, self.xml_data)
 
 class MediaInfoLibraryTest(unittest.TestCase):
     def setUp(self):
@@ -60,8 +69,8 @@ class MediaInfoLibraryTest(unittest.TestCase):
         self.assertEqual(self.mi.tracks[1].track_type, "Video")
         self.assertEqual(self.mi.tracks[2].track_type, "Audio")
     def test_track_details(self):
-        self.assertEqual(self.mi.tracks[1].codec, "AVC")
-        self.assertEqual(self.mi.tracks[2].codec, "AAC LC")
+        self.assertEqual(self.mi.tracks[1].format, "AVC")
+        self.assertEqual(self.mi.tracks[2].format, "AAC")
         self.assertEqual(self.mi.tracks[1].duration, 958)
         self.assertEqual(self.mi.tracks[2].duration, 980)
 
@@ -90,11 +99,21 @@ class MediaInfoURLTest(unittest.TestCase):
 
 class MediaInfoPathlibTest(unittest.TestCase):
     def setUp(self):
-        pathlib = pytest.importorskip("pathlib")
-        self.path = pathlib.Path(data_dir) / "sample.mp4"
+        self.pathlib = pytest.importorskip("pathlib")
     def test_parse_pathlib_path(self):
-        mi = MediaInfo.parse(self.path)
+        path = self.pathlib.Path(data_dir) / "sample.mp4"
+        mi = MediaInfo.parse(path)
         self.assertEqual(len(mi.tracks), 3)
+    @pytest.mark.skipif(os_is_nt, reason="Windows paths are URLs")
+    def test_parse_non_existent_path_pathlib(self):
+        path = self.pathlib.Path(data_dir) / "this file does not exist"
+        self.assertRaises(FileNotFoundError, MediaInfo.parse, path)
+
+class MediaInfoTestParseNonExistentFile(unittest.TestCase):
+    @pytest.mark.skipif(os_is_nt, reason="Windows paths are URLs")
+    def test_parse_non_existent_path(self):
+        path = os.path.join(data_dir, "this file does not exist")
+        self.assertRaises(FileNotFoundError, MediaInfo.parse, path)
 
 class MediaInfoCoverDataTest(unittest.TestCase):
     def setUp(self):
@@ -108,3 +127,15 @@ class MediaInfoCoverDataTest(unittest.TestCase):
                 "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAACXBIWXMAAAAAAA"
                 "AAAQCEeRdzAAAADUlEQVR4nGP4x8DwHwAE/AH+QSRCQgAAAABJRU5ErkJggg=="
         )
+
+class MediaInfoTrackParsingTest(unittest.TestCase):
+    def test_track_parsing(self):
+        mi = MediaInfo.parse(os.path.join(data_dir, "issue55.flv"))
+        self.assertEqual(len(mi.tracks), 2)
+
+class MediainfoRuntimeErrorTest(unittest.TestCase):
+    def test_parse_invalid_url(self):
+        # This is the easiest way to cause a parsing error
+        # since non-existent files return a different exception
+        self.assertRaises(RuntimeError, MediaInfo.parse,
+                "unsupportedscheme://")
